// Javascript functions for insertImg Dialog

// Helper Functions
function getTargetDOM(){
  return self.opener.content.document;
}

function getTargetElement(){
  return getTargetDOM().kaizou_focus;
}

function getKaizouDocument(){
  return getTargetDOM().kaizou_doc;
}

function getKaizouActions(){
  return getTargetDOM().kaizou_actions;
}

function getSRC(){
  return document.getElementById("src").value;
}

function getXPOS(){
  return parseInt(
        document.getElementById("xpos").value ?
         document.getElementById("xpos").value : 0);
}

function setXPOS(value){
  document.getElementById("xpos").value = value; 
}

function getYPOS(){
  return parseInt(
        document.getElementById("ypos").value ?
         document.getElementById("ypos").value : 0);
}

function setYPOS(value){
  document.getElementById("ypos").value = value; 
}

function getPreview(){
  return document.getElementById("preview").checked; 
}

// Clear a previously inserted image
function clearPreview(){
  // Get the target DOM document
  var domDoc = getTargetDOM();
  // Get the target element
  var elt = getTargetElement();
  // Get the current Kaizou insert node
  var actions = getKaizouActions();
  // If we have already inserted something, remove it
  if(domDoc.kaizou_tmp_node != null){
    elt.parentNode.removeChild(domDoc.kaizou_tmp_node);
    domDoc.kaizou_tmp_node = null;
  }
  if(domDoc.kaizou_tmp_action != null){
    actions.removeChild(domDoc.kaizou_tmp_action);
    domDoc.kaizou_tmp_action = null;
  }
}

// Inserts the overlay image (as a tmp node if isPreview == true)
function doInsert(isPreview)
{
  // Get values from the window
  var src  = getSRC();
  var xpos = getXPOS();
  var ypos = getYPOS();
  // Get the target DOM document
  var domDoc = getTargetDOM();
  // Get the target element
  var elt = getTargetElement();
  // Get the current Kaizou document
  var kdoc = getKaizouDocument();
  // Get the current actions node
  var actions = getKaizouActions();
  
  if(kdoc && elt && actions && src != ""){
    // Do the actual insertion
    if(isPreview){
      // Create a new action and store it
      domDoc.kaizou_tmp_action = addImgOverAction(kdoc,actions,src,xpos,ypos);
      // Apply transformations to the DOM in the window that opened this box
      domDoc.kaizou_tmp_node = insertImg(domDoc,elt,domDoc.kaizou_tmp_action);
    }else{
      // Add a new action to the pending kaizou transformation
      var action = addImgOverAction(kdoc,actions,src,xpos,ypos);
      // Apply transformations to the DOM in the window that opened this box
      insertImg(domDoc,elt,action);
    }
  }
}

////////////////////////////////////////////////////////////////////////////////
// Event Handlers
////////////////////////////////////////////////////////////////////////////////

// Preview button event handler
function doRefresh(previewOn)
{
  // If we have already inserted something, remove it
  clearPreview();
  if(previewOn){
    doInsert(true);
  }
}

// OK button event handler
function doOK(){
  // If we have already inserted something, remove it
  clearPreview();
  doInsert(false);
}

// Cancel button event handler
function doCancel()
{
  // If we have already inserted something, remove it
  clearPreview();
}
